/*global describe, it, before*/
'use strict';

require('es6-promise').polyfill();
GLOBAL.fetch = require('node-fetch');
var api = require('../main');

var nock = require('nock');
var expect = require('chai').expect;

nock('https://elastic-search-host')
	.post('/v1_api_v2/item/_search?search_type=count', /"item\.metadata\.taxonomy\.term\.name":"success"/)
	.reply(200, require('./fixtures/related-tags-elastic.json'));

nock('https://elastic-search-host')
	.post('/v1_api_v2/item/_search?search_type=count', /"item\.metadata\.taxonomy\.term\.name":"failure"/)
	.reply(200, { ok: false });

describe('related tags', function() {

	describe('success', function() {

		var subject, options;

		before(function() {
			return api.relatedTags(options = {
				taxonomies: [ 'topics' ],
				taxonomy: 'taxonomy',
				name: 'success',
				range: 100
			})
				.then(function(data) {
					subject = data;
				});
		});

		it('returns an one-dimensional array of objects', function() {
			expect(subject).to.be.an('array');
			expect(subject.length).to.equal(10);

			subject.forEach(function(tag) {
				expect(tag).to.be.an('object');
			});
		});

		it('returns an array sorted by object property', function() {
			expect(subject[0].doc_count).to.be.gt(subject[subject.length - 1].doc_count);
		});

		it('returns each tag with mapped name and taxonomy', function() {
			expect(subject[0].name).to.eq('European banks');
			expect(subject[0].taxonomy).to.eq('topics');
		});

	});

	describe('failure', function() {

		var subject, options;

		before(function() {
			return api.relatedTags(options = {
				taxonomies: [ 'topics' ],
				taxonomy: 'taxonomy',
				name: 'failure',
				range: 100
			})
				.then(function(data) {
					subject = data;
				});
		});

		it('still returns an array', function() {
			expect(subject).to.be.an('array');
			expect(subject.length).to.equal(0);
		});

	});

});
